[RFC PATCH 06/11] MIPS: OCTEON: rename __cvmx_helper_npi/rgmii_probe

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Rename __cvmx_helper_npi/rgmii_probe to __cvmx_helper_npi/rgmii_enumerate
as only latter are used.

Signed-off-by: Aaro Koskinen <aaro.koskinen@xxxxxx>
---
 arch/mips/cavium-octeon/executive/cvmx-helper.c  | 12 ++++++------
 arch/mips/include/asm/octeon/cvmx-helper-npi.h   |  7 +++----
 arch/mips/include/asm/octeon/cvmx-helper-rgmii.h |  7 +++----
 3 files changed, 12 insertions(+), 14 deletions(-)

diff --git a/arch/mips/cavium-octeon/executive/cvmx-helper.c b/arch/mips/cavium-octeon/executive/cvmx-helper.c
index de6e619..c0c541b 100644
--- a/arch/mips/cavium-octeon/executive/cvmx-helper.c
+++ b/arch/mips/cavium-octeon/executive/cvmx-helper.c
@@ -308,15 +308,15 @@ static int __cvmx_helper_loop_enumerate(int interface)
 }
 
 /**
  * Probe a NPI interface and determine the number of ports
  * connected to it. The NPI interface should still be down
  * after this call.
  *
  * @interface: Interface to probe
  *
  * Returns Number of ports on the interface. Zero to disable.
  */
-int __cvmx_helper_npi_probe(int interface)
+int __cvmx_helper_npi_enumerate(int interface)
 {
 #if CVMX_PKO_QUEUES_PER_PORT_PCI > 0
 	if (OCTEON_IS_MODEL(OCTEON_CN38XX) || OCTEON_IS_MODEL(OCTEON_CN58XX))
@@ -346,13 +346,13 @@ int __cvmx_helper_npi_probe(int interface)
 }
 
 /**
  * Probe RGMII ports and determine the number present
  *
  * @interface: Interface to probe
  *
  * Returns Number of RGMII/GMII/MII ports (0-4).
  */
-int __cvmx_helper_rgmii_probe(int interface)
+int __cvmx_helper_rgmii_enumerate(int interface)
 {
 	int num_ports = 0;
 	union cvmx_gmxx_inf_mode mode;
@@ -308,15 +308,15 @@ static int __cvmx_helper_loop_enumerate(int interface)
 
 /**
- * Probe a NPI interface and determine the number of ports
+ * Enumerate a NPI interface and determine the number of ports
  * connected to it. The NPI interface should still be down
  * after this call.
@@ -308,15 +308,15 @@ static int __cvmx_helper_loop_enumerate(int interface)
  * after this call.
  *
- * @interface: Interface to probe
+ * @interface: Interface to enumerate
  *
  * Returns Number of ports on the interface. Zero to disable.
@@ -346,13 +346,13 @@ int __cvmx_helper_npi_probe(int interface)
 
 /**
- * Probe RGMII ports and determine the number present
+ * Enumerate RGMII ports and determine the number present
  *
@@ -346,13 +346,13 @@ int __cvmx_helper_npi_probe(int interface)
  *
- * @interface: Interface to probe
+ * @interface: Interface to enumerate
  *
  * Returns Number of RGMII/GMII/MII ports (0-4).
diff --git a/arch/mips/include/asm/octeon/cvmx-helper-npi.h b/arch/mips/include/asm/octeon/cvmx-helper-npi.h
index 8df4c7f..bab9931 100644
--- a/arch/mips/include/asm/octeon/cvmx-helper-npi.h
+++ b/arch/mips/include/asm/octeon/cvmx-helper-npi.h
@@ -36,16 +36,15 @@
 #define __CVMX_HELPER_NPI_H__
 
 /**
  * Probe a NPI interface and determine the number of ports
  * connected to it. The NPI interface should still be down after
  * this call.
  *
  * @interface: Interface to probe
  *
  * Returns Number of ports on the interface. Zero to disable.
  */
-extern int __cvmx_helper_npi_probe(int interface);
-#define __cvmx_helper_npi_enumerate __cvmx_helper_npi_probe
+extern int __cvmx_helper_npi_enumerate(int interface);
 
 /**
  * Bringup and enable a NPI interface. After this call packet
@@ -36,16 +36,15 @@
 
 /**
- * Probe a NPI interface and determine the number of ports
+ * Enumerate a NPI interface and determine the number of ports
  * connected to it. The NPI interface should still be down after
  * this call.
@@ -36,16 +36,15 @@
  * this call.
  *
- * @interface: Interface to probe
+ * @interface: Interface to enumerate
  *
  * Returns Number of ports on the interface. Zero to disable.
diff --git a/arch/mips/include/asm/octeon/cvmx-helper-rgmii.h b/arch/mips/include/asm/octeon/cvmx-helper-rgmii.h
index 4d7a3db..df7717b 100644
--- a/arch/mips/include/asm/octeon/cvmx-helper-rgmii.h
+++ b/arch/mips/include/asm/octeon/cvmx-helper-rgmii.h
@@ -36,14 +36,13 @@
 #define __CVMX_HELPER_RGMII_H__
 
 /**
  * Probe RGMII ports and determine the number present
  *
  * @interface: Interface to probe
  *
  * Returns Number of RGMII/GMII/MII ports (0-4).
  */
-extern int __cvmx_helper_rgmii_probe(int interface);
-#define __cvmx_helper_rgmii_enumerate __cvmx_helper_rgmii_probe
+extern int __cvmx_helper_rgmii_enumerate(int interface);
 
 /**
  * Put an RGMII interface in loopback mode. Internal packets sent
@@ -36,14 +36,13 @@
 
 /**
- * Probe RGMII ports and determine the number present
+ * Enumerate RGMII ports and determine the number present
  *
@@ -36,14 +36,13 @@
  *
- * @interface: Interface to probe
+ * @interface: Interface to enumerate
  *
  * Returns Number of RGMII/GMII/MII ports (0-4).
-- 
2.3.3






[Index of Archives]     [Linux MIPS Home]     [LKML Archive]     [Linux ARM Kernel]     [Linux ARM]     [Linux]     [Git]     [Yosemite News]     [Linux SCSI]     [Linux Hams]

  Powered by Linux